Structs
- Builtin
Files - Embedded builtin workflow files (compiled into the binary).
Functions
- extract_
builtin_ to_ temp - Extract a builtin to a temporary directory and return its path.
- get_
generate_ builtin - list_
builtins - List all available builtin names.
- resolve_
workflow_ path - Resolve a workflow path that might be a builtin (@name) or a regular file path.